OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Εσφαλμένο συνθηματικό",
    "The new password can not be the same as the previous one" : "Το νέο συνθηματικό δεν μπορεί να είναι το ίδιο με το προηγούμενο",
    "No user supplied" : "Δεν εισήχθη χρήστης",
    "Authentication error" : "Σφάλμα πιστοποίησης",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Παρακαλώ εισάγετε ένα συνθηματικό ανάκτησης διαχειριστή, διαφορετικά όλα τα δεδομένα χρήστη θα χαθούν.",
    "Wrong admin recovery password. Please check the password and try again." : "Λάθος κωδικός ανάκτησης διαχειριστή. Παρακαλώ ελέγξτε τον κωδικό και δοκιμάστε ξανά.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Το σύστημα δεν υποστηρίζει αλλαγή κωδικού, αλλά το κλειδί κρυπτογράφησης του χρήστη ενημερώθηκε επιτυχώς.",
    "Unable to change password" : "Αδυναμία αλλαγής συνθηματικού",
    "%s password changed successfully" : "ο %s άλλαξε το συνθηματικό επιτυχώς",
    "Couldn't send reset email. Please contact your administrator." : "Αδυναμία αποστολής ηλ. μηνύματος επαναφοράς. Παρακαλώ επικοινωνήστε με το διαχειριστή σας.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "εγκατάσταση και ενημέρωση εφαρμογών μέσω του καταστήματος εφαρμογών ή του ",
    "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "Το cURL χρησιμοποιεί μια παρωχημένη %s έκδοση (%s). Παρακαλούμε αναβαθμίστε το λειτουργικό σας σύστημα αλλιώς δυνατότητες όπως %s δεν θα δουλέψουν αξιόπιστα.",
    "A problem occurred, please check your log files (Error: %s)" : "Παρουσιάστηκε πρόβλημα, παρακαλώ ελέγξτε τα αρχεία καταγραφής σας (Σφάλμα: %s)",
    "Migration Completed" : "Η μετάβαση ολοκληρώθηκε",
    "Group already exists." : "Η ομάδα υπάρχει ήδη.",
    "Unable to add group." : "Αδυναμία προσθήκης ομάδας.",
    "Unable to delete group." : "Αδυναμία διαγραφής ομάδας.",
    "log-level out of allowed range" : "Το επίπεδο καταγραφής είναι εκτός του επιτρεπόμενου πεδίου",
    "Saved" : "Αποθηκεύτηκαν",
    "test email settings" : "δοκιμή ρυθμίσεων email",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Παρουσιάστηκε σφάλμα κατά την αποστολή e-mail. Παρακαλώ ελέγξτε τις ρυθμίσεις σας.(Error: %s)",
    "Email sent" : "Το Email απεστάλη ",
    "You need to set your user email before being able to send test emails." : "Πρέπει να ορίσετε το email του χρήστη πριν να είστε σε θέση να στείλετε δοκιμαστικά emails.",
    "Couldn't change the email address because the user does not exist" : "Αδυναμία αλλαγής διεύθυνσης ηλεκτρονικού ταχυδρομείου διότι δεν υπάρχει ο χρήστης",
    "Couldn't change the email address because the token is invalid" : "Αδυναμία αλλαγής διεύθυνσης ηλεκτρονικού ταχυδρομείου λόγω μη έγκυρου διακριτικού",
    "Invalid mail address" : "Μη έγκυρη διεύθυνση ταχυδρομείου.",
    "A user with that name already exists." : "Υπάρχει ήδη χρήστης με το ίδιο όνομα",
    "Unable to create user." : "Αδυναμία δημιουργίας χρήστη.",
    "Your %s account was created" : "Ο λογαριασμός %s δημιουργήθηκε",
    "Unable to delete user." : "Αδυναμία διαγραφής χρήστη.",
    "Forbidden" : "Δεν επιτρέπεται",
    "Invalid user" : "Μη έγκυρος χρήστης",
    "Unable to change mail address" : "Αδυναμία αλλαγής διεύθυνσης αλληλογραφίας",
    "Email has been changed successfully." : "Η διεύθυνση άλλαξε επιτυχώς.",
    "An email has been sent to this address for confirmation" : "Στάλθηκε μήνυμα στην διεύθυνση αυτή για επιβεβαίωση",
    "No email was sent because you already sent one recently. Please try again later." : "Δεν στάλθηκε μήνυμα διότι έχει σταλεί ένα πρόσφατα. Παρακαλώ προσπαθήστε αργότερα.",
    "Your full name has been changed." : "Το πλήρες όνομά σας άλλαξε.",
    "Unable to change full name" : "Δεν ήταν δυνατή η αλλαγή του πλήρους ονόματός σας",
    "%s email address confirm" : "%s η διεύθυνση email επιβεβαιώθηκε",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Αδυναμία αποστολής μηνύματος επιβεβαίωσης αλλαγής διεύθυνσης ηλεκτρονικής αλληλογραφίας. Παρακαλώ επικοινωνήστε με τον διαχειριστή.",
    "%s email address changed successfully" : "ο %s άλλαξε την διεύθυνση ηλεκτρονικής αλληλογραφίας επιτυχώς",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Αδυναμία αποστολής μηνύματος ειδοποίησης αλλαγής διεύθυνσης ηλεκτρονικής αλληλογραφίας. Παρακαλώ επικοινωνήστε με τον διαχειριστή.",
    "Unable to enable/disable user." : "Αδυναμία ενεργοποίησης/απενεργοποίησης χρήστη.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "__όνομα_γλώσσας__",
    "Language changed" : "Η γλώσσα άλλαξε",
    "Invalid request" : "Μη έγκυρο αίτημα",
    "Admins can't remove themself from the admin group" : "Οι διαχειριστές δεν μπορούν να αφαιρέσουν τους εαυτούς τους από την ομάδα των διαχειριστών",
    "Unknown user" : "Άγνωστος χρήστης",
    "Couldn't remove app." : "Αδυναμία αφαίρεσης εφαρμογής.",
    "Official" : "Επίσημο",
    "Approved" : "Εγκεκριμένο",
    "All" : "Όλες",
    "Enabled" : "Ενεργοποιημένο",
    "Not enabled" : "Μη ενεργοποιημένο",
    "No apps found for your version" : "Δεν βρέθηκαν εφαρμογές για αυτή την έκδοση",
    "The app will be downloaded from the app store" : "Η εφαρμογή θα ληφθεί από το κέντρο εφαρμογών",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Οι επίσημες εφαρμογές αναπτύσσονται από την κοινότητα ownCloud. Προσφέρουν λειτουργικότητα κοντά στο ownCloud και είναι έτοιμες για χρήση.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Οι εγκεκριμένες εφαρμογές αναπτύχθηκαν από αξιόπιστους προγραμματιστές και έχουν περάσει έναν συνοπτικό έλεγχο ασφαλείας. Διατηρούνται ενεργά σε ένα αποθετήριο ανοιχτού κώδικα και οι συντηρητές θεωρούν οτι είναι σταθερές για κανονική χρήση.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Η εφαρμογή αυτή δεν ελέγχεται για θέματα ασφάλειας και είναι νέα ή είναι γνωστό ότι είναι ασταθής. Η εγκατάσταση γίνεται με δική σας ευθύνη.",
    "Please wait...." : "Παρακαλώ περιμένετε...",
    "Error while disabling app" : "Σφάλμα κατά την απενεργοποίηση εισόδου",
    "Disable" : "Απενεργοποίηση",
    "Enable" : "Ενεργοποίηση",
    "Error while enabling app" : "Σφάλμα κατά την ενεργοποίηση της εφαρμογής",
    "Error: this app cannot be enabled because it makes the server unstable" : "Σφάλμα: αυτή η εφαρμογή δεν μπορεί να ενεργοποιηθεί διότι καθιστά τον διακομιστή ασταθή",
    "Error: could not disable broken app" : "Σφάλμα: αδυναμία απενεργοποίησης κατεστραμμένης εφαρμογής",
    "Error while disabling broken app" : "Σφάλμα κατά την απενεργοποίηση κατεστραμμένης εφαρμογής",
    "Updating...." : "Ενημέρωση...",
    "Error while updating app" : "Σφάλμα κατά την ενημέρωση της εφαρμογής",
    "Updated" : "Ενημερώθηκε",
    "Uninstalling ...." : "Απεγκατάσταση ....",
    "Error while uninstalling app" : "Σφάλμα κατά την απεγκατάσταση της εφαρμογής",
    "Uninstall" : "Απεγκατάσταση",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Η εφαρμογή έχει ενεργοποιηθεί αλλά χρειάζεται ενημέρωση. Θα μεταφερθείτε στη σελίδα ενημέρωσης σε 5 δευτερόλεπτα.",
    "App update" : "Ενημέρωση εφαρμογής",
    "Experimental" : "Πειραματικό",
    "No apps found for {query}" : "Δεν βρέθηκαν εφαρμογές για {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Είστε πραγματικά σίγουροι ότι θέλετε να προσθέσετε το \"{domain}\" σαν αξιόπιστη περιοχή;",
    "Add trusted domain" : "Προσθέστε αξιόπιστη περιοχή",
    "Migration in progress. Please wait until the migration is finished" : "Μετάβαση σε εξέλιξη. Παρακαλούμε περιμένετε μέχρι να ολοκληρωθεί η μετάβαση",
    "Migration started …" : "Η μετάβαση ξεκίνησε ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Προέκυψε σφάλμα. Παρακαλούμε μεταφορτώστε ένα πιστοποιητικό PEM κωδικοποιημένο κατά ASCII.",
    "Valid until {date}" : "Έγκυρο έως {date}",
    "Delete" : "Διαγραφή",
    "Disconnect" : "Αποσύνδεση",
    "Error while loading browser sessions and device tokens" : "Σφάλμα κατά την φόρτωση των συνεδριών και των διακριτικών συσκευής",
    "Error while creating device token" : "Σφάλμα κατά την δημιουργία διακριτικού συσκευής",
    "Error while deleting the token" : "Σφάλμα κατά την διαγραφή διακριτικού",
    "Sending..." : "Αποστέλεται...",
    "Failed to change the email address." : "Απέτυχε η αλλαγή διεύθυνσης ηλεκτρονικής αλληλογραφίας.",
    "Email changed successfully." : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας άλλαξε επιτυχώς.",
    "An error occurred: {message}" : "Παρουσιάστηκε σφάλμα: {message}",
    "Select a profile picture" : "Επιλογή εικόνας προφίλ",
    "Very weak password" : "Πολύ αδύναμο συνθηματικό",
    "Weak password" : "Αδύναμο συνθηματικό",
    "So-so password" : "Μέτριο συνθηματικό",
    "Good password" : "Καλό συνθηματικό",
    "Strong password" : "Δυνατό συνθηματικό",
    "Groups" : "Ομάδες",
    "Unable to delete {objName}" : "Αδυναμία διαγραφής του {objName}",
    "Error creating group: {message}" : "Σφάλμα δημιουργίας ομάδας: {message}",
    "A valid group name must be provided" : "Πρέπει να δοθεί ένα έγκυρο όνομα ομάδας",
    "deleted {groupName}" : "διαγραφή {groupName}",
    "undo" : "αναίρεση",
    "never" : "ποτέ",
    "deleted {userName}" : "διαγραφή {userName}",
    "add group" : "προσθήκη ομάδας",
    "Invalid quota value \"{val}\"" : "Μη έγκυρη τιμή χώρου \"{val}\"",
    "enabled" : "ενεργοποιημένο",
    "disabled" : "απενεργοποιημένο",
    "User {uid} has been {state}!" : "Ο χρήστης {uid} έχει {state}!",
    "no group" : "καμια ομάδα",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Η αλλαγή του κωδικού πρόσβασης θα έχει ως αποτέλεσμα την απώλεια δεδομένων, επειδή η ανάκτηση δεδομένων δεν είναι διαθέσιμη γι' αυτόν τον χρήστη",
    "Password successfully changed" : "Επιτυχία αλλαγής συνθηματικού",
    "A valid username must be provided" : "Πρέπει να δοθεί έγκυρο όνομα χρήστη",
    "Error creating user: {message}" : "Σφάλμα δημιουργίας χρήστη: {message}",
    "A valid password must be provided" : "Πρέπει να δοθεί έγκυρο συνθηματικό",
    "A valid email must be provided" : "Πρέπει να εισαχθεί ένα έγκυρο email",
    "Use the following link to confirm your changes to the email address: {link}" : "Χρησιμοποιήστε τον ακόλουθο σύνδεσμο για να επιβεβαιώσετε τις αλλαγές στην διεύθυνση ηλεκτρονικής αλληλογραφίας: {link}",
    "Email address changed to {mailAddress} successfully." : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας άλλαξε επιτυχώς σε {mailAddress}.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Χαίρεται,<br><br>απλά σας κάνουμε γνωστό ότι διαθέτετε έναν %s λογαριασμό.<br><br>Το όνομά σας είναι: %s<br>Έχετε πρόσβαση: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Χαιρετισμούς!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Χαίρεται, \nαπλά σας κάνουμε γνωστό ότι διαθέτετε έναν %s λογαριασμό.\nΤο όνομά σας είναι: %s\nΈχετε πρόσβαση: %s\n",
    "User documentation" : "Τεκμηρίωση Χρήστη",
    "Administrator documentation" : "Τεκμηρίωση Διαχειριστή",
    "Online documentation" : "Τεκμηρίωση στο Διαδίκτυο",
    "Forum" : "Φόρουμ",
    "Issue tracker" : "Ιχνηλάτης ζητημάτων",
    "Commercial support" : "Εμπορική Υποστήριξη",
    "Apps Management" : "Διαχείριση εφαρμογών",
    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
    "by %s" : "από τον %s",
    "%s-licensed" : "%s-αδειοδοτημένο",
    "Documentation:" : "Τεκμηρίωση:",
    "Admin documentation" : "Τεκμηρίωση Διαχειριστή",
    "Visit website" : "Προβολή ιστοσελίδας",
    "Report a bug" : "Αναφορά σφάλματος",
    "Show description …" : "Εμφάνιση περιγραφής",
    "Hide description …" : "Απόκρυψη περιγραφής",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Δεν έχει ανατεθεί ελάχιστη έκδοση ownCloud σε αυτή την εφαρμογή. Αυτό μπορεί να είναι σφάλμα από την έκδοση ownCloud 11 και μετά.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Δεν έχει ανατεθεί μέγιστη έκδοση ownCloud σε αυτή την εφαρμογή. Αυτό μπορεί να είναι σφάλμα από την έκδοση ownCloud 11 και μετά.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Αυτή η εφαρμογή δεν μπορεί να εγκατασταθεί διότι δεν εκπληρώνονται οι ακόλουθες εξαρτήσεις:",
    "Enable only for specific groups" : "Ενεργοποίηση μόνο για καθορισμένες ομάδες",
    "Uninstall App" : "Απεγκατάσταση Εφαρμογής",
    "Show enabled apps" : "Εμφάνιση ενεργοποιημένων εφαρμογών",
    "Show disabled apps" : "Εμφάνιση απενεργοποιημένων εφαρμογών",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Τελευταία εκτέλεση cron job: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Τελευταία εκτέλεση cron job: %s. Κάτι πήγε στραβά.",
    "Cron was not executed yet!" : "Η διεργασία cron δεν έχει εκτελεστεί ακόμα!",
    "Open documentation" : "Ανοιχτή τεκμηρίωση.",
    "Execute one task with each page loaded" : "Εκτελεί μια διεργασία κάθε φορά που φορτώνεται μια σελίδα",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "Το cron.php είναι καταχωρημένο σε μια υπηρεσία webcron ώστε να καλεί το cron.php κάθε 15 λεπτά μέσω http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συτήματος για να καλέσετε το cron.php αρχείο κάθε 15 λεπτά.",
    "SSL Root Certificates" : "Πιστοποιητικά SSL root",
    "Common Name" : "Κοινό Όνομα",
    "Valid until" : "Έγκυρο έως",
    "Issued By" : "Έκδόθηκε από",
    "Valid until %s" : "Έγκυρο έως %s",
    "Import root certificate" : "Εισαγωγή Πιστοποιητικού Root",
    "Server-side encryption" : "Κρυπτογράφηση από τον Διακομιστή",
    "Enable server-side encryption" : "Ενεργοποίηση κρυπτογράφησης από το διακομιστή",
    "Please read carefully before activating server-side encryption: " : "Παρακαλούμε διαβάστε προσεκτικά πριν ενεργοποιήσετε την κρυπτογράφηση στο διακομιστή:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Μόλις ενεργοποιηθεί η κρυπτογράφηση, όλα τα αρχεία που θα μεταφορτωθούν από αυτό το σημείο και μετά θα κρυπτογραφηθούν στο διακομιστή. Η κρυπτογράφηση είναι δυνατόν να απενεργοποιηθεί αργότερα μόνο αν το ενεργό άρθρωμα κρυπτογράφησης υποστηρίζει αυτή τη λειτουργία και εκπληρούνται όλες οι προϋποθέσεις (πχ ορισμός κλειδιού ανάκτησης).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Η κρυπτογράφηση από΄μ9ονη της δεν εγγυάται την την ασφάλεια του συστήματος. Παρακαλούμε δείτε την τεκμηρίωση του ownCloud για περισσότερες πληροφορίες σχετικά με το πως δουλεύει η εφαρμογή κρυπτογράφησης και τις υποστηριζόμενες περιπτώσεις χρήσης.",
    "Be aware that encryption always increases the file size." : "Έχετε στο νου σας πως η κρυπτογράφηση πάντα αυξάνει το μέγεθος του αρχείου",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Είναι πάντοτε καλό να δημιουργείτε τακτικά αντίγραφα ασφαλείας των δεδομένων σας, στην περίπτωση της κρυπτογράφησης βεβαιωθείτε ότι έχετε λάβει αντίγραφο ασφαλείας των κλειδιών κρυπτογράφησης παράλληλα με τα δεδομένα σας.",
    "This is the final warning: Do you really want to enable encryption?" : "Αυτή είναι η τελευταία προειδοποίηση: Θέλετε πραγματικά να ενεργοποιήσετε την κρυπτογράφηση;",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Δεν έχει φορτωθεί μονάδα κρυπτογράφησης, παρακαλούμε φορτώστε μια μονάδα κρυπτογράφησης από το μενού εφαρμογών.",
    "Select default encryption module:" : "Επιλογή προεπιλεγμένης μονάδας κρυπτογράφησης:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Πρέπει να μεταφέρετε τα κλειδιά κρυπτογράφησής σας από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια. Παρακαλούμε ενεργοποιήστε την \"Προεπιλεγμένη Μονάδα Κρυπτογράφησης\" και εκτελέστε την εντολή 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Πρέπει να μεταφέρετε τα κλειδιά σας κρυπτογράφησης από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια.",
    "Start migration" : "Έναρξη μετάβασης",
    "Sharing" : "Διαμοιρασμός",
    "Allow apps to use the Share API" : "Επιτρέπει την χρήση του API διαμοιρασμού σε εφαρμογές ",
    "Allow users to share via link" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μέσω συνδέσμου",
    "Allow public uploads" : "Επιτρέπεται το κοινόχρηστο ανέβασμα",
    "Enforce password protection" : "Επιβολή προστασίας με κωδικό",
    "Set default expiration date" : "Ορισμός ερήμην ημερομηνίας λήξης",
    "Allow users to send mail notification for shared files" : "Επιτρέψτε στους χρήστες να στέλνουν ειδοποιήσεις μέσω ηλεκτρονικού ταχυδρομείου για κοινόχρηστα αρχεία",
    "Allow users to share file via social media" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός αρχείου μέσω κοινωνικών δικτύων",
    "Expire after " : "Λήξη μετά από",
    "days" : "ημέρες",
    "Enforce expiration date" : "Επιβολή της ημερομηνίας λήξης",
    "Allow resharing" : "Επιτρέπεται ο επαναδιαμοιρασμός",
    "Allow sharing with groups" : "Να επιτρέπεται διαμοιρασμός με ομάδες",
    "Restrict users to only share with users in their groups" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μόνο με χρήστες που ανήκουν στις ομάδες τους",
    "Allow users to send mail notification for shared files to other users" : "Να επιτρέπεται η αποστολή ειδοποιήσεων σε άλλους χρήστες, μέσω αλληλογραφίας για κοινόχρηστα αρχεία",
    "Exclude groups from sharing" : "Εξαίρεση ομάδων από τον διαμοιρασμό",
    "These groups will still be able to receive shares, but not to initiate them." : "Αυτές οι ομάδες θα συνεχίσουν να λαμβάνουν διαμοιρασμούς, αλλά δεν θα είναι δυνατό να τους δημιουργήσουν.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Να επιτρέπεται η χρήση αυτόματης συμπλήρωσης στο διάλογο διαμοιρασμού. Αν αυτό είναι απενεργοποιημένο θα πρέπει να εισαχθεί το πλήρες όνομα χρήστη.",
    "Restrict enumeration to group members" : "Περιορίστε την απαρίθμηση στα μέλη της ομάδας",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Όλα (καίρια ζητήματα, σφάλματα, προειδοποιήσεις, πληροφορίες, αποσφαλμάτωση)",
    "Info, warnings, errors and fatal issues" : "Πληροφορίες, προειδοποιήσεις, σφάλματα και καίρια ζητήματα",
    "Warnings, errors and fatal issues" : "Προειδοποιήσεις, σφάλματα και καίρια ζητήματα",
    "Errors and fatal issues" : "Σφάλματα και καίρια ζητήματα",
    "Fatal issues only" : "Καίρια ζητήματα μόνο",
    "Log" : "Καταγραφές",
    "What to log" : "Τι να αποθηκευτεί στο ιστορικό",
    "Download logfile (%s)" : "Λήψη αρχείου ιστορικού (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Το αρχείο ιστορικού είναι μεγαλύτερο από 100ΜΒ. Η λήψη του ίσως πάρει λίγη ώρα!",
    "None" : "Τίποτα",
    "Login" : "Σύνδεση",
    "Plain" : "Απλό",
    "NT LAN Manager" : "Διαχειριστης NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Διακομιστής Email",
    "This is used for sending out notifications." : "Χρησιμοποιείται για αποστολή ειδοποιήσεων.",
    "Send mode" : "Κατάσταση αποστολής",
    "Encryption" : "Κρυπτογράφηση",
    "From address" : "Από τη διεύθυνση",
    "mail" : "ταχυδρομείο",
    "Authentication method" : "Μέθοδος πιστοποίησης",
    "Authentication required" : "Απαιτείται πιστοποίηση",
    "Server address" : "Διεύθυνση διακομιστή",
    "Port" : "Θύρα",
    "Credentials" : "Πιστοποιητικά",
    "SMTP Username" : "Όνομα χρήστη SMTP",
    "SMTP Password" : "Συνθηματικό SMTP",
    "Store credentials" : "Διαπιστευτήρια αποθήκευσης",
    "Test email settings" : "Δοκιμή ρυθμίσεων email",
    "Send email" : "Αποστολή email",
    "Security & setup warnings" : "Προειδοποιήσεις ασφάλειας & ρυθμίσεων",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Η php δεν φαίνεται να είναι σωστά ρυθμισμένη για ερωτήματα σε μεταβλητές περιβάλλοντος του συστήματος. Η δοκιμή με την εντολή getenv(\"PATH\") επιστρέφει κενή απάντηση.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Παρακαλούμε ελέγξτε την <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">τεκμηρίωση της εγκατάστασης ↗</a> για τις σημειώσεις σχετικά με τη διαμόρφωση της php και τη διαμόρφωση της php στο διακομιστή σας, ειδικά όταν χρησιμοποιείτε php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Η ρύθμιση  \"μόνο ανάγνωση\"  έχει ενεργοποιηθεί. Αυτό εμποδίζει τον καθορισμό κάποιων ρυθμίσεων μέσω της διεπαφής web. Επιπλέον, το αρχείο πρέπει να γίνει χειροκίνητα εγγράψιμο πριν από κάθε διαδικασία ενημέρωσης.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Ο PHP φαίνεται να είναι ρυθμισμένος ώστε να αφαιρεί μπλοκ εσωτερικών κειμένων (inline doc). Αυτό θα καταστήσει κύριες εφαρμογές μη-διαθέσιμες.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Αυτό πιθανόν προκλήθηκε από προσωρινή μνήμη (cache)/επιταχυντή όπως τη Zend OPcache ή τον eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Η βάση δεδομένων σας δεν λειτουργεί με στάθμη απομόνωσης συναλλαγής «READ COMMITED». Αυτό μπορεί να προκαλέσει προβλήματα όταν πολλαπλές δράσεις εκτελούνται παράλληλα.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Είναι εγκατεστημένο το %1$s έκδοση %2$s, για λόγους σταθερότητας και απόδοσης συστήνουμε να αναβαθμίσετε σε νεότερη έκδοση του %1$s.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Το άρθρωμα PHP 'fileinfo' λείπει. Σας συνιστούμε να ενεργοποιήσετε αυτό το άρθρωμα για να έχετε καλύτερα αποτελέσματα με τον εντοπισμό τύπου MIME. ",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Το Transactional file locking είναι απενεργοποιημένο, αυτό μπορεί να οδηγήσει σε προβλήματα με τις race conditions. Ενεργοποιήστε το 'filelocking.enabled' στο config.php για να αποφύγετε αυτά τα προβλήματα. Δείτε την <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">τεκμηρίωση ↗</a> για περισσότερες πληροφορίες.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Το Transactional file locking πρέπει ρυθμιστεί ώστε να χρησιμοποιείται το memory-based locking, και όχι το προεπιλεγμένο αργό database-based locking. Για περισσότερες πληροφορίες δείτε την <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">τεκμηρίωση ↗</a>.",
    "System locale can not be set to a one which supports UTF-8." : "Οι ρυθμίσεις τοποθεσίας συστήματος δεν μπορούν να οριστούν σε κάποιες που δεν υποστηρίζουν UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Αυτό σημαίνει ότι μπορεί να υπάρχουν προβλήματα με κάποιους χαρακτήρες στα ονόματα αρχείων.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Προτείνουμε ανεπιφύλακτα να εγκαταστήσετε  στο σύστημά σας τα απαιτούμενα πακέτα έτσι ώστε να υποστηρίζεται μια από τις ακόλουθες ρυθμίσεις τοποθεσίας: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Αν η εγκατάστασή σας δεν έχει γίνει στο root του τομέα  και χρησιμοποιείται το cron του συστήματος, μπορεί να υπάρξουν ζητήματα με τη δημιουργία URL. Για να αποφύγετε αυτά τα προβλήματα, παρακαλώ ρυθμίστε την επιλογή  \"overwrite.cli.url\" στο αρχείο  config.php που βρίσκεται στη διαδρομή webroot της εγκατάστασής σας (Suggested: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Ως βάση δεδομένων χρησιμοποιείται η SQLite. Για μεγαλύτερες εγκαταστάσεις συνιστούμε να επιλέξετε ένα διαφορετικό σύστημα υποστήριξης βάσης δεδομένων.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Ειδικά όταν χρησιμοποιείτε τον πελάτη για συγχρονισμό στον υπολογιστή σας, δεν συνίσταται η χρήση της SQLite.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Για να μεταφέρετε σε άλλη βάση δεδομένων χρησιμοποιήστε το εργαλείο της γραμμή εντολών: 'occ db:convert-type', ή ανατρέξτε στην <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">τεκμηρίωση ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Σας συνιστούμε να ενεργοποιήσετε το cron του συστήματος καθώς οποιαδήποτε άλλη μέθοδος cron θα έχει πιθανές επιπτώσεις απόδοσης και αξιοπιστίας.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Δεν ήταν δυνατή η εκτέλεση της cronjob μέσω τερματικού. Εμφανίστηκαν τα παρακάτω τεχνικά σφάλματα:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Παρακαλώ ελέγξτε ξανά τα <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">εγχειρίδια εγκατάστασης ↗</a>,  καθώς επίσης και για τυχόν σφάλματα ή προειδοποιήσεις στο <a href=\"#log-section\">ιστορικό</a>.",
    "All checks passed." : "Όλοι οι έλεγχοι επιτυχείς.",
    "System Status" : "Κατάσταση συστήματος",
    "Tips & tricks" : "Συμβουλές & τεχνάσματα",
    "How to do backups" : "Πώς να κάνετε αντίγραφα ασφαλείας",
    "Advanced monitoring" : "Παρακολούθηση για προχωρημένους",
    "Performance tuning" : "Ρύθμιση βελτίωσης της απόδοσης",
    "Improving the config.php" : "Βελτίωση του  config.php",
    "Theming" : "Θέματα",
    "Hardening and security guidance" : "Οδηγίες ασφάλειας και θωράκισης",
    "Get the apps to sync your files" : "Λήψη της εφαρμογής για συγχρονισμό των αρχείων σας",
    "Desktop client" : "Πελάτης σταθερού υπολογιστή",
    "Android app" : "Εφαρμογή Android",
    "iOS app" : "Εφαρμογή iOS",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Εάν θέλετε να υποστηρίξετε το έργο\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">συμμετέχετε στην ανάπτυξη</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">συμμετέχετε στην διάδωση</a>!",
    "Show First Run Wizard again" : "Προβολή Οδηγού Πρώτης Εκτέλεσης ξανά",
    "Profile picture" : "Φωτογραφία προφίλ",
    "Upload new" : "Μεταφόρτωση νέου",
    "Select from Files" : "Επιλογή από Αρχεία",
    "Remove image" : "Αφαίρεση εικόνας",
    "png or jpg, max. 20 MB" : "png ή jpg, μέγ. 20 MB",
    "Picture provided by original account" : "Φωτογραφία που παρέχεται από τον αρχικό σας λογαριασμό",
    "Cancel" : "Άκυρο",
    "Choose as profile picture" : "Επιλογή εικόνας προφίλ",
    "Full name" : "Πλήρες όνομα",
    "No display name set" : "Δεν ορίστηκε όνομα",
    "Email" : "Ηλεκτρονικό ταχυδρομείο",
    "Your email address" : "Η διεύθυνση ηλ. ταχυδρομείου σας",
    "Change email" : "Αλλαγή διεύθυνσης ηλεκτρονικής αλληλογραφίας",
    "Set email" : "Ορισμός διεύθυνσης ηλεκτρονικής αλληλογραφίας",
    "For password recovery and notifications" : "Για ανάκτηση κωδικού και ειδοποιήσεις",
    "No email address set" : "Δεν ορίστηκε διεύθυνση email",
    "You are member of the following groups:" : "Είστε μέλος των ακόλουθων ομάδων:",
    "Password" : "Συνθηματικό",
    "Unable to change your password" : "Δεν ήταν δυνατή η αλλαγή του κωδικού πρόσβασης",
    "Current password" : "Τρέχων συνθηματικό",
    "New password" : "Νέο συνθηματικό",
    "Change password" : "Αλλαγή συνθηματικού",
    "Language" : "Γλώσσα",
    "Help translate" : "Βοηθήστε στη μετάφραση",
    "Unlimited" : "Απεριόριστο",
    "You are using %s of %s" : "Χρησιμοποιείτε %s από %s",
    "You are using %s of %s (%s %%)" : "Χρησιμοποιείτε %s από %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Αναπτύχθηκε από την {communityopen}  κοινότητα του  ownCloud {linkclose}, ο {githubopen}  πηγαίος κώδικας {linkclose} έχει την άδεια της {licenseopen} <abbr title = \"Affero General Public License\"> AGPL </ abbr> {linkclose}.",
    "Sessions" : "Συνεδρίες",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Αυτοί είναι οι πελάτες για το δίκτυο, το σταθερό υπολογιστή και το κινητό που έχουν εισέλθει στο ownCloud.",
    "Browser" : "Περιηγητής",
    "Most recent activity" : "Τελευταία δραστηριότητα",
    "App passwords" : "Συνθηματικά εφαρμογής",
    "You've linked these apps." : "Έχετε συνδέσει αυτές τις εφαρμογές.",
    "Name" : "Όνομα",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Το συνθηματικό της εφαρμογής είναι ένας κωδικός πρόσβασης που παρέχει στην εφαρμογή ή στην συσκευή το δικαίωμα να έχει πρόσβαση στον λογαριασμό %s.",
    "App name" : "Όνομα εφαρμογής",
    "Create new app password" : "Δημιουργία νέου κωδικού εφαρμογής",
    "Use the credentials below to configure your app or device." : "Χρήση των παρακάτω διαπιστευτηρίων για να ρυθμίσετε την εφαρμογή ή την συσκευή.",
    "Username" : "Όνομα χρήστη",
    "Done" : "Ολοκληρώθηκε",
    "Version" : "Έκδοση",
    "Personal" : "Προσωπικά",
    "Admin" : "Διαχείριση",
    "Error" : "Σφάλμα",
    "No panels for this section." : "Κανένας πίνακας γι' αυτή την ενότητα.",
    "Show enabled/disabled option" : "Εμφάνιση επιλογής ενεργοποίησης/απενεργοποίησης",
    "Show storage location" : "Εμφάνιση τοποθεσίας αποθήκευσης",
    "Show last log in" : "Εμφάνιση τελευταίας εισόδου",
    "Show user backend" : "Εμφάνιση χρήστη συστήματος υποστήριξης",
    "Send email to new user" : "Αποστολή μηνύματος στο νέο χρήστη",
    "Show email address" : "Εμφάνιση διεύθυνσης ηλ. αλληλογραφίας",
    "E-Mail" : "Ηλεκτρονική αλληλογραφία",
    "Create" : "Δημιουργία",
    "Admin Recovery Password" : "Κωδικός Επαναφοράς Διαχειριστή ",
    "Enter the recovery password in order to recover the users files during password change" : "Εισάγετε το συνθηματικό ανάκτησης ώστε να ανακτήσετε τα αρχεία χρηστών κατά την αλλαγή συνθηματικού",
    "Add Group" : "Προσθήκη Ομάδας",
    "Group" : "Ομάδα",
    "Everyone" : "Όλοι",
    "Admins" : "Διαχειριστές",
    "Default Quota" : "Προεπιλεγμένο Όριο",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Παρακαλώ εισάγετε επιτρεπόμενα μερίδια αποθηκευτικού χώρου (π.χ. \"512 MB\"  ή \"12 GB\")",
    "Other" : "Άλλο",
    "Full Name" : "Πλήρες όνομα",
    "Group Admin for" : "Διαχειριστής ομάδας για",
    "Quota" : "Σύνολο Χώρου",
    "Storage Location" : "Τοποθεσία αποθηκευτικού χώρου",
    "User Backend" : "Χρήστης συστήματος υποστήριξης",
    "Last Login" : "Τελευταία Σύνδεση",
    "change full name" : "αλλαγή πλήρους ονόματος",
    "set new password" : "επιλογή νέου κωδικού",
    "change email address" : "αλλαγή διεύθυνσης ηλ. αλληλογραφίας",
    "Default" : "Προκαθορισμένο",
    "Share" : "Μοιράσου",
    "Domain" : "Τομέας",
    "Add Domain" : "Προσθήκη τομέα",
    "Add" : "Προσθήκη"
},
"nplurals=2; plural=(n != 1);");
